@@ -4,6 +4,7 @@ from .message import Message
 from .connection import Connection
 from .util import check_type
 import re
+from json_cpp import JsonList, JsonObject
 
 
 class Router:
@@ -18,9 +19,22 @@ class Router:
         check_type(handler, (types.FunctionType, types.MethodType), "incorrect type for handler")
         self.routes[pattern] = (handler, body_type)
 
+    def get_manifest(self):
+        manifest = JsonList()
+        for pattern in self.routes.keys():
+            (handler, body_type) = self.routes[pattern]
+            if body_type:
+                body_type_str = body_type.__name__
+            else:
+                body_type_str = ""
+            manifest.append(JsonObject(route=pattern, input_type=body_type_str))
+        return manifest
+
     def route(self, message: Message):
         responses = []
         check_type(message, Message, "incorrect type for message")
+        if message.header == "!manifest":
+            responses.append(self.get_manifest())
         for pattern in self.routes.keys():
             if re.search(pattern, message.header):
                 (handler, body_type) = self.routes[pattern]
@@ -96,10 +110,11 @@ class RouterProcess:
             if clean_up_required:
                 RouterProcess.__mutex.acquire()
                 for failed_connection in clean_up_required:
-                    del self.connections[failed_connection]
+                    try:
+                        del self.connections[failed_connection]
+                    except:
+                        pass
                 if len(self.connections) == 0:
                     RouterProcess.__handler = None
                     self.running = False
                 RouterProcess.__mutex.release()
-
-
